@@ -1,5 +1,6 @@
 # coding: utf-8
 
+
 """
     Creole wiki markup parser
 
@@ -17,21 +18,15 @@
       unrecognized schemes (like wtf://server/path) triggering italic rendering
       for the rest of the paragraph.
 
-
-    @copyright: 2007 MoinMoin:RadomirDopieralski (creole 0.5 implementation),
-                2007 MoinMoin:ThomasWaldmann (updates)
-                2008-2010 JensDiemer
-    @license: GNU GPL v3 or above, see LICENSE for details.
+    :copyleft: 2008-2011 by python-creole team, see AUTHORS for more details.
+    :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
+
 import re
 
 
-
-
-
-
-class InlineRules:
+class InlineRules(object):
     """
     All inline rules
     """
@@ -112,7 +107,7 @@ class InlineRules:
 
 
 
-class BlockRules:
+class BlockRules(object):
     """
     All used block rules.
     """
@@ -141,7 +136,7 @@ class BlockRules:
         ^
         (?P<head_head>=+) \s*
         (?P<head_text> .*? )
-        =*$
+        (=|\s)*?$
     )'''
     separator = r'(?P<separator> ^ \s* ---- \s* $ )' # horizontal line
 
@@ -165,11 +160,28 @@ class BlockRules:
             [|]?
         ) \s* $'''
 
+    re_flags = re.VERBOSE | re.UNICODE | re.MULTILINE
 
-    text = r'(?P<text> .+ ) (?P<break> (?<!\\)$\n(?!\s*$) )?'
+    def __init__(self, blog_line_breaks=True):
+        if blog_line_breaks:
+            # use blog style line breaks (every line break would be convertet into <br />) 
+            self.text = r'(?P<text> .+ ) (?P<break> (?<!\\)$\n(?!\s*$) )?'
+        else:
+            # use wiki style line breaks
+            self.text = r'(?P<text> .+ )'
+
+        self.rules = (
+            self.macro_block,
+            self.line, self.head, self.separator,
+            self.pre_block, self.list,
+            self.table, self.text,
+        )
 
 
-class SpecialRules:
+
+
+
+class SpecialRules(object):
     """
     re rules witch not directly used as inline/block rules.
     """
@@ -197,15 +209,6 @@ class SpecialRules:
     pre_escape = r' ^(?P<indent>\s*) ~ (?P<rest> \}\}\} \s*) $'
 
 
-
-BLOCK_FLAGS = re.VERBOSE | re.UNICODE | re.MULTILINE
-BLOCK_RULES = (
-    BlockRules.macro_block,
-    BlockRules.line, BlockRules.head, BlockRules.separator,
-    BlockRules.pre_block, BlockRules.list,
-    BlockRules.table, BlockRules.text,
-)
-
 INLINE_FLAGS = re.VERBOSE | re.UNICODE
 INLINE_RULES = (
     InlineRules.link, InlineRules.url,
@@ -276,15 +279,19 @@ class Parser:
     # for table cells:
     cell_re = re.compile(SpecialRules.cell, re.VERBOSE | re.UNICODE)
 
-    # For block elements:
-    block_re = re.compile('|'.join(BLOCK_RULES), BLOCK_FLAGS)
-
     # For inline elements:
     inline_re = re.compile('|'.join(INLINE_RULES), INLINE_FLAGS)
 
-    def __init__(self, raw):
+
+    def __init__(self, raw, block_rules=None):
         assert isinstance(raw, unicode)
         self.raw = raw
+
+        # setup block element rules:
+        if not block_rules:
+            block_rules = BlockRules()
+        self.block_re = re.compile('|'.join(block_rules.rules), block_rules.re_flags)
+
         self.root = DocNode('document', None)
         self.cur = self.root        # The most recent document node
         self.text = None            # The node to add inline characters to
