@@ -1,15 +1,17 @@
 # coding: utf-8
 
+
 """
     html2creole
     ~~~~~~~~~~~
    
     created by Jens Diemer
 
-    :copyleft: 2009-2010 by the python-creole team, see AUTHORS for more details.
+    :copyleft: 2009-2011 by the python-creole team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
+
 import re
 import inspect
 import warnings
@@ -98,10 +100,11 @@ class DocNode:
         return u" ".join(attr_list)
 
     def __str__(self):
-        return "<DocNode %s: %r>" % (self.kind, self.content)
+        return str(self.__repr__())
 
     def __repr__(self):
         return u"<DocNode %s: %r>" % (self.kind, self.content)
+#        return u"<DocNode %s (parent: %r): %r>" % (self.kind, self.parent, self.content)
 
     def debug(self):
         print "_" * 80
@@ -168,7 +171,12 @@ def strip_html(html_code):
 
     >>> strip_html(u'<p>a <pre> preformated area </pre> foo </p>')
     u'<p>a<pre>preformated area</pre>foo</p>'
+    
+    FIXME:
+    >>> strip_html(u'<strong>foo</strong>\\n<ul><li>one</li></ul>')
+    u'<strong>foo</strong><ul><li>one</li></ul>'
     """
+
     def strip_tag(match):
         block = match.group(0)
         end_tag = match.group("end") in ("/", u"/")
@@ -566,6 +574,7 @@ class Html2CreoleEmitter(object):
         else:
             raise AssertionError("wrong keyword argument 'unknown_emit'!")
 
+        self.last = None
         self.debugging = debug
 
         self.deentity = Deentity() # for replacing html entities
@@ -757,8 +766,12 @@ class Html2CreoleEmitter(object):
         return u"\n%s %s" % (self.__inner_list, content)
 
     def _list_emit(self, node, list_type):
+        start_newline = False
+        if self.last and self.last.kind not in BLOCK_TAGS:
+            if not self.last.content or not self.last.content.endswith("\n"):
+                start_newline = True
 
-        if self.__inner_list == "": # Srart a new list
+        if self.__inner_list == "": # Start a new list
             self.__inner_list = list_type
         else:
             start = False
@@ -768,8 +781,11 @@ class Html2CreoleEmitter(object):
 
         self.__inner_list = self.__inner_list[:-1]
 
-        if self.__inner_list == "": # Srart a new list
-            return content.strip() + "\n\n"
+        if self.__inner_list == "": # Start a new list
+            if start_newline:
+                return "\n" + content + "\n\n"
+            else:
+                return content.strip() + "\n\n"
         else:
             return content
 
@@ -816,11 +832,26 @@ class Html2CreoleEmitter(object):
 
     #--------------------------------------------------------------------------
 
+    def _emit_content(self, node):
+        content = self.emit_children(node)
+        content = self._escape_linebreaks(content)
+        return content
+
+    def div_emit(self, node):
+        return self._emit_content(node)
+
+    def span_emit(self, node):
+        return self._emit_content(node)
+
+    #--------------------------------------------------------------------------
+
     def document_emit(self, node):
+        self.last = node
         return self.emit_children(node)
 
     def emit_children(self, node):
         """Emit all the children of a node."""
+        self.last = node
         result = []
         for child in node.children:
             content = self.emit_node(child)
@@ -843,6 +874,7 @@ class Html2CreoleEmitter(object):
                     method_name, content
                 )
             )
+        self.last = node
         return content
 
     def emit(self):
@@ -936,7 +968,9 @@ if __name__ == '__main__':
 #    import sys;sys.exit()
 
     data = u"""
-<p>one<br></br>two</p>
+<b>foo</b> <ul><li>one</li></ul>
+
+<b>foo2</b><ul><li>one2</li></ul>
 """
 
 #    print data.strip()
