@@ -1,5 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
+# coding: utf-8
+
+
 """
     creole2html unittest
     ~~~~~~~~~~~~~~~~~~~~
@@ -10,18 +12,12 @@
         between creol2html and html2creole.
 
     Test the creole markup.
-    
 
-    Last commit info:
-    ~~~~~~~~~~~~~~~~~
-    $LastChangedDate$
-    $Rev$
-    $Author$
-
-    :copyleft: 2008-2009 by python-creole team, see AUTHORS for more details.
-    :license: GNU GPL v3 or above, see LICENSE.txt for more details.
+    :copyleft: 2008-2011 by python-creole team, see AUTHORS for more details.
+    :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
+
 import unittest
 import StringIO
 
@@ -30,8 +26,6 @@ from tests.utils.base_unittest import BaseCreoleTest
 from creole import creole2html
 
 
-
-
 class TestCreole2html(unittest.TestCase):
     """
     Tests around creole2html API and macro function.
@@ -204,21 +198,6 @@ class TestCreole2htmlMarkup(BaseCreoleTest):
             [[Link]]</p>
         """)
 
-    def test_cross_lines(self):
-        """
-        TODO: bold/italics cross lines
-        see: http://code.google.com/p/python-creole/issues/detail?id=13 
-        """
-        self.assertCreole(r"""
-            Bold and italics should //be
-            able// to **cross
-            lines.**
-        """, """
-            <p>Bold and italics should <i>be<br />
-            able</i> to <strong>cross<br />
-            lines.</strong></p>
-        """)
-
     def test_cross_paragraphs(self):
         self.assertCreole(r"""
             Bold and italics should //not be...
@@ -376,6 +355,19 @@ class TestCreole2htmlMarkup(BaseCreoleTest):
             <img src="/path1/path2/foobar3.jpg" alt="foobar3.jpg" /></p>
         """)
 
+    def test_image_unknown_extension(self):
+        self.assertCreole(r"""
+            # {{/path/to/image.ext|image ext}} one
+            # {{/no/extension|no extension}} two
+            # {{/image.xyz}} tree
+        """, """
+            <ol>
+                <li><img src="/path/to/image.ext" alt="image ext" /> one</li>
+                <li><img src="/no/extension" alt="no extension" /> two</li>
+                <li><img src="/image.xyz" alt="/image.xyz" /> tree</li>
+            </ol>
+        """)
+
     def test_links(self):
         self.assertCreole(r"""
             [[/foobar/Creole_(Markup)]]
@@ -415,6 +407,61 @@ class TestCreole2htmlMarkup(BaseCreoleTest):
             
         """))
 
+    def test_wiki_style_line_breaks(self):
+
+        html = creole2html(
+            markup_string=self._prepare_text(u"""
+                with blog line breaks, every line break would be convertet into <br />
+                with wiki style not.
+                
+                This is the first line,\\\\and this is the second.
+                
+                new line
+                 block 1
+                
+                new line
+                 block 2
+                
+                end
+            """),
+            blog_line_breaks=False
+        )
+        self.assertEqual(html, self._prepare_text(u"""
+            <p>with blog line breaks, every line break would be convertet into &lt;br /&gt;with wiki style not.</p>
+            
+            <p>This is the first line,<br />
+            and this is the second.</p>
+            
+            <p>new line block 1</p>
+            
+            <p>new line block 2</p>
+            
+            <p>end</p>
+            
+        """))
+
+
+    def test_headline_spaces(self):
+        """
+        https://code.google.com/p/python-creole/issues/detail?id=15
+        """
+        html = creole2html(markup_string=u"== Headline1 == \n== Headline2== ")
+        self.assertEqual(html, self._prepare_text(u"""
+            <h2>Headline1</h2>
+            <h2>Headline2</h2>
+            
+        """))
+
+    def test_tt(self):
+        self.assertCreole(r"""
+            inline {{{<escaped>}}} and {{{ **not strong** }}}...
+            ...and ##**strong** Teletyper## ;)
+        """, """
+            <p>inline <tt>&lt;escaped&gt;</tt> and <tt> **not strong** </tt>...<br />
+            ...and <tt><strong>strong</strong> Teletyper</tt> ;)</p>
+        """)
+
+
 
 if __name__ == '__main__':
     unittest.main()
