@@ -1,5 +1,6 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
+# coding: utf-8
+
 
 """
     cross compare unittest
@@ -11,16 +12,11 @@
     Note: This only works fine if there is no problematic whitespace handling.
         In this case, we must test in test_creole2html.py or test_html2creole.py
 
-    Last commit info:
-    ~~~~~~~~~~~~~~~~~
-    $LastChangedDate$
-    $Rev$
-    $Author$
-
     :copyleft: 2008-2009 by python-creole team, see AUTHORS for more details.
-    :license: GNU GPL v3 or above, see LICENSE.txt for more details.
+    :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
+
 import unittest
 
 from tests.utils.base_unittest import BaseCreoleTest
@@ -87,26 +83,25 @@ class CrossCompareTests(BaseCreoleTest):
             no __ underline</p>
         """, debug=False)
 
-    def test_internal_links(self):
+    def test_links(self):
         self.assertCreole(r"""
             A [[internal]] link...
             ...and [[/a internal]] link.
-        """, """
-            <p>A <a href="internal">internal</a> link...<br />
-            ...and <a href="/a internal">/a internal</a> link.</p>
-        """)
-
-    def test_external_links(self):
-        self.assertCreole(r"""
+        
             With pipe separator:
             1 [[internal links|link A]] test.
             2 [[http://domain.tld|link B]] test.
             3 [[http://de.wikipedia.org/wiki/Creole_(Markup)|Creole@wikipedia]]
+            4 [[Foo://bar|unknown protocol]]
         """, """
+            <p>A <a href="internal">internal</a> link...<br />
+            ...and <a href="/a internal">/a internal</a> link.</p>
+            
             <p>With pipe separator:<br />
             1 <a href="internal links">link A</a> test.<br />
             2 <a href="http://domain.tld">link B</a> test.<br />
-            3 <a href="http://de.wikipedia.org/wiki/Creole_(Markup)">Creole@wikipedia</a></p>
+            3 <a href="http://de.wikipedia.org/wiki/Creole_(Markup)">Creole@wikipedia</a><br />
+            4 <a href="Foo://bar">unknown protocol</a></p>
         """)
 
     def test_bolditalic_links(self):
@@ -137,15 +132,8 @@ class CrossCompareTests(BaseCreoleTest):
             <a href="http://example.com/"><img src="myimage.jpg" alt="example site" /></a></p>
         """)
 
-    def test_nowiki1(self):
+    def test_pre_contains_braces(self):
         self.assertCreole(r"""
-            this:
-
-            {{{
-            //This// does **not** get [[formatted]]
-            }}}
-            and this: {{{** <i>this</i> **}}}
-
             === Closing braces in nowiki:
             {{{
             if (x != NULL) {
@@ -155,13 +143,6 @@ class CrossCompareTests(BaseCreoleTest):
               }}}
             }}}
         """, """
-            <p>this:</p>
-
-            <pre>
-            //This// does **not** get [[formatted]]
-            </pre>
-            <p>and this: <pre>** &lt;i&gt;this&lt;/i&gt; **</pre></p>
-
             <h3>Closing braces in nowiki:</h3>
             <pre>
             if (x != NULL) {
@@ -172,19 +153,17 @@ class CrossCompareTests(BaseCreoleTest):
             </pre>
         """)
 
-    def test_nowiki2(self):
+    def test_pre2(self):
         self.assertCreole(r"""
-            111 {{{ inline pre }}} 222
-            333
-
+            111
+            
             {{{
-            pre line 1
-            pre line 2
+            //This// does **not** get [[formatted]]
             }}}
-            444
+            222
 
             one
-
+            
             {{{
             foo
 
@@ -192,17 +171,15 @@ class CrossCompareTests(BaseCreoleTest):
             }}}
             two
         """, """
-            <p>111 <pre> inline pre </pre> 222<br />
-            333</p>
-
+            <p>111</p>
+            
             <pre>
-            pre line 1
-            pre line 2
+            //This// does **not** get [[formatted]]
             </pre>
-            <p>444</p>
-
+            <p>222</p>
+            
             <p>one</p>
-
+            
             <pre>
             foo
 
@@ -211,6 +188,31 @@ class CrossCompareTests(BaseCreoleTest):
             <p>two</p>
         """)
 
+    def test_pre(self):
+        self.assertCreole(r"""
+            start
+            
+            {{{
+            * no list
+            <html escaped>
+            }}}
+            end
+        """, """
+            <p>start</p>
+            
+            <pre>
+            * no list
+            &lt;html escaped&gt;
+            </pre>
+            <p>end</p>
+        """)
+
+    def test_tt(self):
+        self.assertCreole(r"""
+            this is ##**strong** Teletyper## ;)
+        """, """
+            <p>this is <tt><strong>strong</strong> Teletyper</tt> ;)</p>
+        """)
 
     def test_headlines(self):
         self.assertCreole(r"""
@@ -371,7 +373,6 @@ class CrossCompareTests(BaseCreoleTest):
             * //italic// item
 
             # item about a [[certain_page]]
-            # {{{//this// is **not** [[processed]]}}}
         """, """
             <ul>
                 <li><strong>bold</strong> item</li>
@@ -379,7 +380,6 @@ class CrossCompareTests(BaseCreoleTest):
             </ul>
             <ol>
                 <li>item about a <a href="certain_page">certain_page</a></li>
-                <li><pre>//this// is **not** [[processed]]</pre></li>
             </ol>
         """)
 
@@ -480,7 +480,6 @@ class CrossCompareTests(BaseCreoleTest):
             greater-than sign: &gt;</p>
         """)
 
-
 #    def test_macro_html1(self):
 #        self.assertCreole(r"""
 #            <<a_not_existing_macro>>
